@@ -166,8 +166,10 @@ def dof(A, tol=0.001, condition=False):
 
     Examples
     --------
-    >>> dof([[2, -1, 3], [1, 0, 1], [0, 2, -1], [1, 1, 4]], condition=True)
-    (0, 1, 5.073596551276727)
+    >>> from numpy import allclose
+    >>> d = dof([[2, -1, 3], [1, 0, 1], [0, 2, -1], [1, 1, 4]], condition=True)
+    >>> allclose(d, (0, 1, 5.073596551))
+    True
 
     """
     A = atleast_2d(asarray(A, dtype=float))
@@ -706,10 +708,9 @@ def spsolve_with_known(A, b, x, known):
     >>> A = array([[2, 1, 3], [2, 6, 8], [6, 8, 18]])
     >>> b = array([[1], [3], [5]])
     >>> x = array([[0.3], [0], [0]])
-    >>> solve_with_known(A, b, x, [0])
-    array([[ 3.00000000e-01],
-           [ 4.00000000e-01],
-           [-6.66247443e-17]])
+    >>> x = solve_with_known(A, b, x, [0])
+    >>> allclose(x, array([[0.3], [0.4], [0.0]]))
+    True
 
     """
     unknown = list(set(range(x.shape[0])) - set(known))
