@@ -33,9 +33,9 @@ class MeshObject(BaseObject):
 
     Parameters
     ----------
-    mesh : :class:`compas.datastructures.Mesh`
+    mesh : :class:`~compas.datastructures.Mesh`
         A mesh data structure.
-    scene : :class:`compas.scenes.Scene`, optional
+    scene : :class:`~compas.scenes.Scene`, optional
         A scene object.
     name : str, optional
         The name of the object.
@@ -112,7 +112,7 @@ class MeshObject(BaseObject):
 
     @property
     def location(self):
-        """:class:`compas.geometry.Point`:
+        """:class:`~compas.geometry.Point`:
         The location of the object.
         Default is the origin of the world coordinate system.
         The object transformation is applied relative to this location.
@@ -398,8 +398,8 @@ class MeshObject(BaseObject):
         Returns
         -------
         bool
-            ``True`` if the update was successful.
-            ``False`` otherwise.
+            True if the update was successful.
+            False otherwise.
         """
         return mesh_update_attributes(self.mesh)
 
@@ -437,8 +437,8 @@ class MeshObject(BaseObject):
         Returns
         -------
         bool
-            ``True`` if the update was successful.
-            ``False`` otherwise.
+            True if the update was successful.
+            False otherwise.
 
         """
         return mesh_update_edge_attributes(self.mesh, edges, names=names)
